:: Windows Batch file version          
@echo off

echo *** OECD 308 utility ***

:: command line parameters: [version] [infilename] [outfilename]

set MODELVERSION=%1
set INFILENAME=%2
set OUTFILENAME=%3

::echo ARGS: %1, %2, %3

:: CHECK MODELVERSION
if [%1]==[] ECHO [Error]: model version (1st argument) is missing! & goto :eof
if %MODELVERSION% == A goto :propervalue
if %MODELVERSION% == B goto :propervalue
if %MODELVERSION% == C goto :propervalue
if %MODELVERSION% == D goto :propervalue
:: MODELVERSION did not pass tests
echo [Error]: model version (1st argument) is not one of A/B/C/D!
goto :eof
:propervalue

:: CHECK INFILENAME
if [%2]==[] echo [Error]: input filename (2nd argument) is missing! & goto :eof
if exist %INFILENAME% goto :properinfile
echo [Error]: Input file not found!
goto :eof
:properinfile

:: CHECK OUTFILENAME
if [%3]==[] echo [Error]: output filename (3rd argument) is missing! & goto :eof

echo Using model version %MODELVERSION%
echo Will read input data from %INFILENAME%
echo Will write results to %OUTFILENAME%

:: read priors from priors.txt
for /f "delims=" %%x in (priors.txt) do (set "%%x")

:: customise contents of layout.xml
call jrepl.bat "\&inputfilename;" "%INFILENAME%" /f layout.xml /o _temporary_layout1.xml
call jrepl.bat "\&modelversion;" "%MODELVERSION%" /f _temporary_layout1.xml /o _temporary_layout2.xml
call jrepl.bat "\&Koc_mean;" "%Koc_mean%" /f _temporary_layout2.xml /o _temporary_layout3.xml
call jrepl.bat "\&Koc_sd;" "%Koc_sd%" /f _temporary_layout3.xml /o _temporary_layout4.xml
call jrepl.bat "\&focsed_mean;" "%focsed_mean%" /f _temporary_layout4.xml /o _temporary_layout5.xml
call jrepl.bat "\&focsed_sd;" "%focsed_sd%" /f _temporary_layout5.xml /o _temporary_layout6.xml
call jrepl.bat "\&dKoc_mean;" "%dKoc_mean%" /f _temporary_layout6.xml /o _temporary_layout7.xml
call jrepl.bat "\&dKoc_sd;" "%dKoc_sd%" /f _temporary_layout7.xml /o layout_spec.xml

del _temporary_layout*

:: substitutions presumably done at this point

:: perform layout test
echo|set /p=--- Testing model layout...    

set ERRORLEVEL=0

server.exe layout_spec.xml EVAL > output.log

if %ERRORLEVEL% GEQ 1 echo [Error]: Model layout test failed. Please check output.log for errors. & goto :eof
echo Passed

:: perform MCMC
echo|set /p=--- Performing MCMC sampling...
echo     (This may take up to 20 minutes)

server.exe layout_spec.xml MCMC %OUTFILENAME% 20000 10000 > output.log
if %ERRORLEVEL% GEQ 1 echo [Error]: MCMC sampling failed. Please check output.log for errors. & goto :eof

echo Finished. Results written to %OUTFILENAME%.
